Re-exports
pub use brave::BraveSearchTool;pub use calculator::CalculatorTool;pub use duckduckgo::DuckDuckGoTool;pub use filter::AllowListFilter;pub use filter::CompositeFilter;pub use filter::DenyListFilter;pub use filter::FilterContext;pub use filter::StateMachineFilter;pub use filter::ToolFilter;pub use jina_reader::JinaReaderTool;pub use wikipedia::WikipediaTool;
Modules
- brave
- Brave Search API tool for privacy-focused web search.
- calculator
- Calculator tool for evaluating mathematical expressions.
- duckduckgo
- DuckDuckGo Instant Answer search tool.
- filter
- jina_
reader - Jina Reader tool — converts any URL to clean Markdown for LLM consumption.
- wikipedia
- Wikipedia search and summary tool.
Structs
- Handle
Error Tool - A tool wrapper that catches errors and returns them as string values instead of propagating them.
- Parallel
Tool Executor - Executes multiple tool calls concurrently using
futures::future::join_all. - Return
Direct Tool - A tool wrapper that signals the agent should return the tool’s output directly to the user without further LLM processing.
- Serial
Tool Executor - Executes tool calls sequentially, looking up tools in a
ToolRegistry. - Tool
Registry - Thread-safe registry for tool definitions and implementations, backed by
Arc<RwLock<HashMap>>.