Skip to main contentModule filter
Source - AllowListFilter
- Only allows tools whose names are in the allow list.
- CompositeFilter
- Composes multiple filters, applying them in sequence.
- DenyListFilter
- Removes tools whose names are in the deny list.
- FilterContext
- Context available when filtering tools.
- StateMachineFilter
- Filters tools based on state machine rules: which tools are allowed
after certain tools, and which tools become available after N turns.
- ToolFilter
- Trait for filtering available tools based on context.